This is an automated email from the ASF dual-hosted git repository.

villebro pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/superset.git


The following commit(s) were added to refs/heads/master by this push:
     new 299635c  docs: add password example to dataset import API (#18580)
299635c is described below

commit 299635c5803db3a1c8be079762d0bb57b4f8fc54
Author: Ville Brofeldt <[email protected]>
AuthorDate: Mon Feb 7 09:38:55 2022 +0200

    docs: add password example to dataset import API (#18580)
---
 superset/charts/api.py                | 7 ++++++-
 superset/dashboards/api.py            | 7 ++++++-
 superset/databases/api.py             | 7 ++++++-
 superset/datasets/api.py              | 7 ++++++-
 superset/queries/saved_queries/api.py | 7 ++++++-
 5 files changed, 30 insertions(+), 5 deletions(-)

diff --git a/superset/charts/api.py b/superset/charts/api.py
index 6b45900..a4a301b 100644
--- a/superset/charts/api.py
+++ b/superset/charts/api.py
@@ -837,7 +837,12 @@ class ChartRestApi(BaseSupersetModelRestApi):
                       type: string
                       format: binary
                     passwords:
-                      description: JSON map of passwords for each file
+                      description: >-
+                        JSON map of passwords for each featured database in the
+                        ZIP file. If the ZIP includes a database config in the 
path
+                        `databases/MyDatabase.yaml`, the password should be 
provided
+                        in the following format:
+                        `{"databases/MyDatabase.yaml": "my_password"}`.
                       type: string
                     overwrite:
                       description: overwrite existing databases?
diff --git a/superset/dashboards/api.py b/superset/dashboards/api.py
index ea05ce9..d5c0480 100644
--- a/superset/dashboards/api.py
+++ b/superset/dashboards/api.py
@@ -944,7 +944,12 @@ class DashboardRestApi(BaseSupersetModelRestApi):
                       type: string
                       format: binary
                     passwords:
-                      description: JSON map of passwords for each file
+                      description: >-
+                        JSON map of passwords for each featured database in the
+                        ZIP file. If the ZIP includes a database config in the 
path
+                        `databases/MyDatabase.yaml`, the password should be 
provided
+                        in the following format:
+                        `{"databases/MyDatabase.yaml": "my_password"}`.
                       type: string
                     overwrite:
                       description: overwrite existing databases?
diff --git a/superset/databases/api.py b/superset/databases/api.py
index 79c4ff7..1b8b408 100644
--- a/superset/databases/api.py
+++ b/superset/databases/api.py
@@ -791,7 +791,12 @@ class DatabaseRestApi(BaseSupersetModelRestApi):
                       type: string
                       format: binary
                     passwords:
-                      description: JSON map of passwords for each file
+                      description: >-
+                        JSON map of passwords for each featured database in the
+                        ZIP file. If the ZIP includes a database config in the 
path
+                        `databases/MyDatabase.yaml`, the password should be 
provided
+                        in the following format:
+                        `{"databases/MyDatabase.yaml": "my_password"}`.
                       type: string
                     overwrite:
                       description: overwrite existing databases?
diff --git a/superset/datasets/api.py b/superset/datasets/api.py
index ce8ce55..b94b9ca 100644
--- a/superset/datasets/api.py
+++ b/superset/datasets/api.py
@@ -697,7 +697,12 @@ class DatasetRestApi(BaseSupersetModelRestApi):
                       type: string
                       format: binary
                     passwords:
-                      description: JSON map of passwords for each file
+                      description: >-
+                        JSON map of passwords for each featured database in the
+                        ZIP file. If the ZIP includes a database config in the 
path
+                        `databases/MyDatabase.yaml`, the password should be 
provided
+                        in the following format:
+                        `{"databases/MyDatabase.yaml": "my_password"}`.
                       type: string
                     overwrite:
                       description: overwrite existing datasets?
diff --git a/superset/queries/saved_queries/api.py 
b/superset/queries/saved_queries/api.py
index a4d74cc..04df234 100644
--- a/superset/queries/saved_queries/api.py
+++ b/superset/queries/saved_queries/api.py
@@ -293,7 +293,12 @@ class SavedQueryRestApi(BaseSupersetModelRestApi):
                       type: string
                       format: binary
                     passwords:
-                      description: JSON map of passwords for each file
+                      description: >-
+                        JSON map of passwords for each featured database in the
+                        ZIP file. If the ZIP includes a database config in the 
path
+                        `databases/MyDatabase.yaml`, the password should be 
provided
+                        in the following format:
+                        `{"databases/MyDatabase.yaml": "my_password"}`.
                       type: string
                     overwrite:
                       description: overwrite existing saved queries?

Reply via email to